# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/math/VectorDouble.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/math/VectorDouble.proto',
  package='rst.math',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/math/VectorDouble.proto\x12\x08rst.math\" \n\x0cVectorDouble\x12\x10\n\x04\x64\x61ta\x18\x02 \x03(\x01\x42\x02\x10\x01\x42\x12\x42\x10VectorDoubleType')
)




_VECTORDOUBLE = _descriptor.Descriptor(
  name='VectorDouble',
  full_name='rst.math.VectorDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.math.VectorDouble.data', index=0,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=73,
)

DESCRIPTOR.message_types_by_name['VectorDouble'] = _VECTORDOUBLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VectorDouble = _reflection.GeneratedProtocolMessageType('VectorDouble', (_message.Message,), dict(
  DESCRIPTOR = _VECTORDOUBLE,
  __module__ = 'rst.math.VectorDouble_pb2'
  # @@protoc_insertion_point(class_scope:rst.math.VectorDouble)
  ))
_sym_db.RegisterMessage(VectorDouble)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020VectorDoubleType'))
_VECTORDOUBLE.fields_by_name['data'].has_options = True
_VECTORDOUBLE.fields_by_name['data']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/CalendarQuery.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/CalendarQuery.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n rst/calendar/CalendarQuery.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\"\xc5\x01\n\rCalendarQuery\x12*\n\nstart_time\x18\x01 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12(\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x1a\n\x0csearch_todos\x18\x03 \x01(\x08:\x04true\x12\x1b\n\rsearch_events\x18\x04 \x01(\x08:\x04true\x12%\n\x16\x63\x61lculate_time_periods\x18\x05 \x01(\x08:\x05\x66\x61lseB\x13\x42\x11\x43\x61lendarQueryType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,])




_CALENDARQUERY = _descriptor.Descriptor(
  name='CalendarQuery',
  full_name='rst.calendar.CalendarQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time', full_name='rst.calendar.CalendarQuery.start_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='rst.calendar.CalendarQuery.end_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='search_todos', full_name='rst.calendar.CalendarQuery.search_todos', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='search_events', full_name='rst.calendar.CalendarQuery.search_events', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='calculate_time_periods', full_name='rst.calendar.CalendarQuery.calculate_time_periods', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=277,
)

_CALENDARQUERY.fields_by_name['start_time'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_CALENDARQUERY.fields_by_name['end_time'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
DESCRIPTOR.message_types_by_name['CalendarQuery'] = _CALENDARQUERY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CalendarQuery = _reflection.GeneratedProtocolMessageType('CalendarQuery', (_message.Message,), dict(
  DESCRIPTOR = _CALENDARQUERY,
  __module__ = 'rst.calendar.CalendarQuery_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.CalendarQuery)
  ))
_sym_db.RegisterMessage(CalendarQuery)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\021CalendarQueryType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tts/Prosody.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tts/Prosody.proto',
  package='rst.tts',
  syntax='proto2',
  serialized_pb=_b('\n\x15rst/tts/Prosody.proto\x12\x07rst.tts\"\xe6\x01\n\x07Prosody\x12%\n\x05pitch\x18\x01 \x01(\x0b\x32\x16.rst.tts.Prosody.Value\x12%\n\x05range\x18\x02 \x01(\x0b\x32\x16.rst.tts.Prosody.Value\x12&\n\x06volume\x18\x03 \x01(\x0b\x32\x16.rst.tts.Prosody.Value\x12\x10\n\x08\x64uration\x18\x04 \x01(\x02\x12\x0f\n\x04rate\x18\x05 \x01(\x02:\x01\x31\x1a\x42\n\x05Value\x12\x10\n\x08\x61\x62solute\x18\x01 \x01(\x02\x12\x10\n\x08relative\x18\x02 \x01(\x02\x12\x15\n\npercentage\x18\x03 \x01(\x02:\x01\x31\x42\rB\x0bProsodyType')
)




_PROSODY_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='rst.tts.Prosody.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='absolute', full_name='rst.tts.Prosody.Value.absolute', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='relative', full_name='rst.tts.Prosody.Value.relative', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='rst.tts.Prosody.Value.percentage', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=199,
  serialized_end=265,
)

_PROSODY = _descriptor.Descriptor(
  name='Prosody',
  full_name='rst.tts.Prosody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pitch', full_name='rst.tts.Prosody.pitch', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='range', full_name='rst.tts.Prosody.range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volume', full_name='rst.tts.Prosody.volume', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='rst.tts.Prosody.duration', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rate', full_name='rst.tts.Prosody.rate', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PROSODY_VALUE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=265,
)

_PROSODY_VALUE.containing_type = _PROSODY
_PROSODY.fields_by_name['pitch'].message_type = _PROSODY_VALUE
_PROSODY.fields_by_name['range'].message_type = _PROSODY_VALUE
_PROSODY.fields_by_name['volume'].message_type = _PROSODY_VALUE
DESCRIPTOR.message_types_by_name['Prosody'] = _PROSODY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Prosody = _reflection.GeneratedProtocolMessageType('Prosody', (_message.Message,), dict(

  Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), dict(
    DESCRIPTOR = _PROSODY_VALUE,
    __module__ = 'rst.tts.Prosody_pb2'
    # @@protoc_insertion_point(class_scope:rst.tts.Prosody.Value)
    ))
  ,
  DESCRIPTOR = _PROSODY,
  __module__ = 'rst.tts.Prosody_pb2'
  # @@protoc_insertion_point(class_scope:rst.tts.Prosody)
  ))
_sym_db.RegisterMessage(Prosody)
_sym_db.RegisterMessage(Prosody.Value)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\013ProsodyType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/bayesnetwork/BayesNetwork.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.bayesnetwork import BayesVariable_pb2 as rst_dot_bayesnetwork_dot_BayesVariable__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/bayesnetwork/BayesNetwork.proto',
  package='rst.bayesnetwork',
  syntax='proto2',
  serialized_pb=_b('\n#rst/bayesnetwork/BayesNetwork.proto\x12\x10rst.bayesnetwork\x1a$rst/bayesnetwork/BayesVariable.proto\"a\n\x0c\x42\x61yesNetwork\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08property\x18\x02 \x03(\t\x12\x31\n\x08variable\x18\x03 \x03(\x0b\x32\x1f.rst.bayesnetwork.BayesVariableB\x12\x42\x10\x42\x61yesNetworkType')
  ,
  dependencies=[rst_dot_bayesnetwork_dot_BayesVariable__pb2.DESCRIPTOR,])




_BAYESNETWORK = _descriptor.Descriptor(
  name='BayesNetwork',
  full_name='rst.bayesnetwork.BayesNetwork',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.bayesnetwork.BayesNetwork.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='property', full_name='rst.bayesnetwork.BayesNetwork.property', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='variable', full_name='rst.bayesnetwork.BayesNetwork.variable', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=192,
)

_BAYESNETWORK.fields_by_name['variable'].message_type = rst_dot_bayesnetwork_dot_BayesVariable__pb2._BAYESVARIABLE
DESCRIPTOR.message_types_by_name['BayesNetwork'] = _BAYESNETWORK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BayesNetwork = _reflection.GeneratedProtocolMessageType('BayesNetwork', (_message.Message,), dict(
  DESCRIPTOR = _BAYESNETWORK,
  __module__ = 'rst.bayesnetwork.BayesNetwork_pb2'
  # @@protoc_insertion_point(class_scope:rst.bayesnetwork.BayesNetwork)
  ))
_sym_db.RegisterMessage(BayesNetwork)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020BayesNetworkType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/generic/Value.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/generic/Value.proto',
  package='rst.generic',
  syntax='proto2',
  serialized_pb=_b('\n\x17rst/generic/Value.proto\x12\x0brst.generic\"\xf0\x01\n\x05Value\x12%\n\x04type\x18\x01 \x02(\x0e\x32\x17.rst.generic.Value.Type\x12\x0b\n\x03int\x18\x02 \x01(\x03\x12\x0e\n\x06\x64ouble\x18\x03 \x01(\x01\x12\x0e\n\x06string\x18\x04 \x01(\t\x12\x0c\n\x04\x62ool\x18\x05 \x01(\x08\x12\x0e\n\x06\x62inary\x18\x06 \x01(\x0c\x12!\n\x05\x61rray\x18\x07 \x03(\x0b\x32\x12.rst.generic.Value\"R\n\x04Type\x12\x08\n\x04VOID\x10\x01\x12\x07\n\x03INT\x10\x02\x12\n\n\x06\x44OUBLE\x10\x03\x12\n\n\x06STRING\x10\x04\x12\x08\n\x04\x42OOL\x10\x05\x12\n\n\x06\x42INARY\x10\x06\x12\t\n\x05\x41RRAY\x10\x07\x42\x0b\x42\tValueType')
)



_VALUE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='rst.generic.Value.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VOID', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INT', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOL', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BINARY', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARRAY', index=6, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=199,
  serialized_end=281,
)
_sym_db.RegisterEnumDescriptor(_VALUE_TYPE)


_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='rst.generic.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rst.generic.Value.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='int', full_name='rst.generic.Value.int', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='double', full_name='rst.generic.Value.double', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string', full_name='rst.generic.Value.string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bool', full_name='rst.generic.Value.bool', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='binary', full_name='rst.generic.Value.binary', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='array', full_name='rst.generic.Value.array', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VALUE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=281,
)

_VALUE.fields_by_name['type'].enum_type = _VALUE_TYPE
_VALUE.fields_by_name['array'].message_type = _VALUE
_VALUE_TYPE.containing_type = _VALUE
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), dict(
  DESCRIPTOR = _VALUE,
  __module__ = 'rst.generic.Value_pb2'
  # @@protoc_insertion_point(class_scope:rst.generic.Value)
  ))
_sym_db.RegisterMessage(Value)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\tValueType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/LocatedFace.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.vision import Face_pb2 as rst_dot_vision_dot_Face__pb2
from rst.geometry import Translation_pb2 as rst_dot_geometry_dot_Translation__pb2
from rst.geometry import Rotation_pb2 as rst_dot_geometry_dot_Rotation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/LocatedFace.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x1crst/vision/LocatedFace.proto\x12\nrst.vision\x1a\x15rst/vision/Face.proto\x1a\x1erst/geometry/Translation.proto\x1a\x1brst/geometry/Rotation.proto\"\x87\x01\n\x0bLocatedFace\x12\x1e\n\x04\x66\x61\x63\x65\x18\x01 \x02(\x0b\x32\x10.rst.vision.Face\x12+\n\x08location\x18\x02 \x01(\x0b\x32\x19.rst.geometry.Translation\x12+\n\x0borientation\x18\x03 \x01(\x0b\x32\x16.rst.geometry.RotationB\x11\x42\x0fLocatedFaceType')
  ,
  dependencies=[rst_dot_vision_dot_Face__pb2.DESCRIPTOR,rst_dot_geometry_dot_Translation__pb2.DESCRIPTOR,rst_dot_geometry_dot_Rotation__pb2.DESCRIPTOR,])




_LOCATEDFACE = _descriptor.Descriptor(
  name='LocatedFace',
  full_name='rst.vision.LocatedFace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='face', full_name='rst.vision.LocatedFace.face', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location', full_name='rst.vision.LocatedFace.location', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='rst.vision.LocatedFace.orientation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=264,
)

_LOCATEDFACE.fields_by_name['face'].message_type = rst_dot_vision_dot_Face__pb2._FACE
_LOCATEDFACE.fields_by_name['location'].message_type = rst_dot_geometry_dot_Translation__pb2._TRANSLATION
_LOCATEDFACE.fields_by_name['orientation'].message_type = rst_dot_geometry_dot_Rotation__pb2._ROTATION
DESCRIPTOR.message_types_by_name['LocatedFace'] = _LOCATEDFACE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocatedFace = _reflection.GeneratedProtocolMessageType('LocatedFace', (_message.Message,), dict(
  DESCRIPTOR = _LOCATEDFACE,
  __module__ = 'rst.vision.LocatedFace_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.LocatedFace)
  ))
_sym_db.RegisterMessage(LocatedFace)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017LocatedFaceType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedPose.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.tracking import TrackingInfo_pb2 as rst_dot_tracking_dot_TrackingInfo__pb2
from rst.geometry import Pose_pb2 as rst_dot_geometry_dot_Pose__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedPose.proto',
  package='rst.tracking',
  syntax='proto2',
  serialized_pb=_b('\n\x1erst/tracking/TrackedPose.proto\x12\x0crst.tracking\x1a\x1frst/tracking/TrackingInfo.proto\x1a\x17rst/geometry/Pose.proto\"\x96\x01\n\x0bTrackedPose\x12(\n\x04info\x18\x01 \x02(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12 \n\x04pose\x18\x02 \x02(\x0b\x32\x12.rst.geometry.Pose\x12\x1e\n\x16translation_confidence\x18\x03 \x01(\x02\x12\x1b\n\x13rotation_confidence\x18\x04 \x01(\x02\x42\x11\x42\x0fTrackedPoseType')
  ,
  dependencies=[rst_dot_tracking_dot_TrackingInfo__pb2.DESCRIPTOR,rst_dot_geometry_dot_Pose__pb2.DESCRIPTOR,])




_TRACKEDPOSE = _descriptor.Descriptor(
  name='TrackedPose',
  full_name='rst.tracking.TrackedPose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='rst.tracking.TrackedPose.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pose', full_name='rst.tracking.TrackedPose.pose', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='translation_confidence', full_name='rst.tracking.TrackedPose.translation_confidence', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation_confidence', full_name='rst.tracking.TrackedPose.rotation_confidence', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=257,
)

_TRACKEDPOSE.fields_by_name['info'].message_type = rst_dot_tracking_dot_TrackingInfo__pb2._TRACKINGINFO
_TRACKEDPOSE.fields_by_name['pose'].message_type = rst_dot_geometry_dot_Pose__pb2._POSE
DESCRIPTOR.message_types_by_name['TrackedPose'] = _TRACKEDPOSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrackedPose = _reflection.GeneratedProtocolMessageType('TrackedPose', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEDPOSE,
  __module__ = 'rst.tracking.TrackedPose_pb2'
  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedPose)
  ))
_sym_db.RegisterMessage(TrackedPose)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017TrackedPoseType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/Face.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import BoundingBox_pb2 as rst_dot_geometry_dot_BoundingBox__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/Face.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x15rst/vision/Face.proto\x12\nrst.vision\x1a\x1erst/geometry/BoundingBox.proto\"E\n\x04\x46\x61\x63\x65\x12)\n\x06region\x18\x01 \x02(\x0b\x32\x19.rst.geometry.BoundingBox\x12\x12\n\nconfidence\x18\x02 \x01(\x01\x42\nB\x08\x46\x61\x63\x65Type')
  ,
  dependencies=[rst_dot_geometry_dot_BoundingBox__pb2.DESCRIPTOR,])




_FACE = _descriptor.Descriptor(
  name='Face',
  full_name='rst.vision.Face',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.vision.Face.region', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='rst.vision.Face.confidence', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=138,
)

_FACE.fields_by_name['region'].message_type = rst_dot_geometry_dot_BoundingBox__pb2._BOUNDINGBOX
DESCRIPTOR.message_types_by_name['Face'] = _FACE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Face = _reflection.GeneratedProtocolMessageType('Face', (_message.Message,), dict(
  DESCRIPTOR = _FACE,
  __module__ = 'rst.vision.Face_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.Face)
  ))
_sym_db.RegisterMessage(Face)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\010FaceType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/graph/EdgeListGraph.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.graph import Node_pb2 as rst_dot_graph_dot_Node__pb2
from rst.graph import Edge_pb2 as rst_dot_graph_dot_Edge__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/graph/EdgeListGraph.proto',
  package='rst.graph',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/graph/EdgeListGraph.proto\x12\trst.graph\x1a\x14rst/graph/Node.proto\x1a\x14rst/graph/Edge.proto\"O\n\rEdgeListGraph\x12\x1e\n\x05nodes\x18\x01 \x03(\x0b\x32\x0f.rst.graph.Node\x12\x1e\n\x05\x65\x64ges\x18\x02 \x03(\x0b\x32\x0f.rst.graph.EdgeB\x13\x42\x11\x45\x64geListGraphType')
  ,
  dependencies=[rst_dot_graph_dot_Node__pb2.DESCRIPTOR,rst_dot_graph_dot_Edge__pb2.DESCRIPTOR,])




_EDGELISTGRAPH = _descriptor.Descriptor(
  name='EdgeListGraph',
  full_name='rst.graph.EdgeListGraph',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='rst.graph.EdgeListGraph.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edges', full_name='rst.graph.EdgeListGraph.edges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=167,
)

_EDGELISTGRAPH.fields_by_name['nodes'].message_type = rst_dot_graph_dot_Node__pb2._NODE
_EDGELISTGRAPH.fields_by_name['edges'].message_type = rst_dot_graph_dot_Edge__pb2._EDGE
DESCRIPTOR.message_types_by_name['EdgeListGraph'] = _EDGELISTGRAPH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EdgeListGraph = _reflection.GeneratedProtocolMessageType('EdgeListGraph', (_message.Message,), dict(
  DESCRIPTOR = _EDGELISTGRAPH,
  __module__ = 'rst.graph.EdgeListGraph_pb2'
  # @@protoc_insertion_point(class_scope:rst.graph.EdgeListGraph)
  ))
_sym_db.RegisterMessage(EdgeListGraph)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\021EdgeListGraphType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/SphericalDirectionFloat.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/SphericalDirectionFloat.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n*rst/geometry/SphericalDirectionFloat.proto\x12\x0crst.geometry\"=\n\x17SphericalDirectionFloat\x12\x0f\n\x07\x61zimuth\x18\x01 \x02(\x02\x12\x11\n\televation\x18\x02 \x02(\x02\x42\x1d\x42\x1bSphericalDirectionFloatType')
)




_SPHERICALDIRECTIONFLOAT = _descriptor.Descriptor(
  name='SphericalDirectionFloat',
  full_name='rst.geometry.SphericalDirectionFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='azimuth', full_name='rst.geometry.SphericalDirectionFloat.azimuth', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='elevation', full_name='rst.geometry.SphericalDirectionFloat.elevation', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=121,
)

DESCRIPTOR.message_types_by_name['SphericalDirectionFloat'] = _SPHERICALDIRECTIONFLOAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SphericalDirectionFloat = _reflection.GeneratedProtocolMessageType('SphericalDirectionFloat', (_message.Message,), dict(
  DESCRIPTOR = _SPHERICALDIRECTIONFLOAT,
  __module__ = 'rst.geometry.SphericalDirectionFloat_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.SphericalDirectionFloat)
  ))
_sym_db.RegisterMessage(SphericalDirectionFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\033SphericalDirectionFloatType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/Twist.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.kinematics import LinearVelocities_pb2 as rst_dot_kinematics_dot_LinearVelocities__pb2
from rst.kinematics import AngularVelocities_pb2 as rst_dot_kinematics_dot_AngularVelocities__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/Twist.proto',
  package='rst.kinematics',
  syntax='proto2',
  serialized_pb=_b('\n\x1arst/kinematics/Twist.proto\x12\x0erst.kinematics\x1a%rst/kinematics/LinearVelocities.proto\x1a&rst/kinematics/AngularVelocities.proto\"m\n\x05Twist\x12\x30\n\x06linear\x18\x01 \x02(\x0b\x32 .rst.kinematics.LinearVelocities\x12\x32\n\x07\x61ngular\x18\x02 \x02(\x0b\x32!.rst.kinematics.AngularVelocitiesB\x0b\x42\tTwistType')
  ,
  dependencies=[rst_dot_kinematics_dot_LinearVelocities__pb2.DESCRIPTOR,rst_dot_kinematics_dot_AngularVelocities__pb2.DESCRIPTOR,])




_TWIST = _descriptor.Descriptor(
  name='Twist',
  full_name='rst.kinematics.Twist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear', full_name='rst.kinematics.Twist.linear', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angular', full_name='rst.kinematics.Twist.angular', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=234,
)

_TWIST.fields_by_name['linear'].message_type = rst_dot_kinematics_dot_LinearVelocities__pb2._LINEARVELOCITIES
_TWIST.fields_by_name['angular'].message_type = rst_dot_kinematics_dot_AngularVelocities__pb2._ANGULARVELOCITIES
DESCRIPTOR.message_types_by_name['Twist'] = _TWIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Twist = _reflection.GeneratedProtocolMessageType('Twist', (_message.Message,), dict(
  DESCRIPTOR = _TWIST,
  __module__ = 'rst.kinematics.Twist_pb2'
  # @@protoc_insertion_point(class_scope:rst.kinematics.Twist)
  ))
_sym_db.RegisterMessage(Twist)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\tTwistType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassificationResult.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassificationResult.proto',
  package='rst.classification',
  syntax='proto2',
  serialized_pb=_b('\n-rst/classification/ClassificationResult.proto\x12\x12rst.classification\"\xb7\x01\n\x14\x43lassificationResult\x12\x15\n\rdecided_class\x18\x01 \x02(\x0c\x12N\n\x07\x63lasses\x18\x02 \x03(\x0b\x32=.rst.classification.ClassificationResult.ClassWithProbability\x1a\x38\n\x14\x43lassWithProbability\x12\x0c\n\x04name\x18\x01 \x02(\x0c\x12\x12\n\nconfidence\x18\x02 \x02(\x02\x42\x1a\x42\x18\x43lassificationResultType')
)




_CLASSIFICATIONRESULT_CLASSWITHPROBABILITY = _descriptor.Descriptor(
  name='ClassWithProbability',
  full_name='rst.classification.ClassificationResult.ClassWithProbability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.classification.ClassificationResult.ClassWithProbability.name', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='rst.classification.ClassificationResult.ClassWithProbability.confidence', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=253,
)

_CLASSIFICATIONRESULT = _descriptor.Descriptor(
  name='ClassificationResult',
  full_name='rst.classification.ClassificationResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='decided_class', full_name='rst.classification.ClassificationResult.decided_class', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='classes', full_name='rst.classification.ClassificationResult.classes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CLASSIFICATIONRESULT_CLASSWITHPROBABILITY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=253,
)

_CLASSIFICATIONRESULT_CLASSWITHPROBABILITY.containing_type = _CLASSIFICATIONRESULT
_CLASSIFICATIONRESULT.fields_by_name['classes'].message_type = _CLASSIFICATIONRESULT_CLASSWITHPROBABILITY
DESCRIPTOR.message_types_by_name['ClassificationResult'] = _CLASSIFICATIONRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassificationResult = _reflection.GeneratedProtocolMessageType('ClassificationResult', (_message.Message,), dict(

  ClassWithProbability = _reflection.GeneratedProtocolMessageType('ClassWithProbability', (_message.Message,), dict(
    DESCRIPTOR = _CLASSIFICATIONRESULT_CLASSWITHPROBABILITY,
    __module__ = 'rst.classification.ClassificationResult_pb2'
    # @@protoc_insertion_point(class_scope:rst.classification.ClassificationResult.ClassWithProbability)
    ))
  ,
  DESCRIPTOR = _CLASSIFICATIONRESULT,
  __module__ = 'rst.classification.ClassificationResult_pb2'
  # @@protoc_insertion_point(class_scope:rst.classification.ClassificationResult)
  ))
_sym_db.RegisterMessage(ClassificationResult)
_sym_db.RegisterMessage(ClassificationResult.ClassWithProbability)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\030ClassificationResultType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/MotionParameters.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/MotionParameters.proto',
  package='rst.navigation',
  syntax='proto2',
  serialized_pb=_b('\n%rst/navigation/MotionParameters.proto\x12\x0erst.navigation\"\xa2\x01\n\x10MotionParameters\x12\x14\n\x0cmax_velocity\x18\x01 \x01(\x02\x12\x18\n\x10max_acceleration\x18\x02 \x01(\x02\x12\x1c\n\x14translation_accuracy\x18\x03 \x01(\x02\x12\x1c\n\x14orientation_accuracy\x18\x04 \x01(\x02\x12\"\n\x1aprefer_forward_orientation\x18\x05 \x01(\x08\x42\x16\x42\x14MotionParametersType')
)




_MOTIONPARAMETERS = _descriptor.Descriptor(
  name='MotionParameters',
  full_name='rst.navigation.MotionParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_velocity', full_name='rst.navigation.MotionParameters.max_velocity', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_acceleration', full_name='rst.navigation.MotionParameters.max_acceleration', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='translation_accuracy', full_name='rst.navigation.MotionParameters.translation_accuracy', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation_accuracy', full_name='rst.navigation.MotionParameters.orientation_accuracy', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prefer_forward_orientation', full_name='rst.navigation.MotionParameters.prefer_forward_orientation', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=220,
)

DESCRIPTOR.message_types_by_name['MotionParameters'] = _MOTIONPARAMETERS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MotionParameters = _reflection.GeneratedProtocolMessageType('MotionParameters', (_message.Message,), dict(
  DESCRIPTOR = _MOTIONPARAMETERS,
  __module__ = 'rst.navigation.MotionParameters_pb2'
  # @@protoc_insertion_point(class_scope:rst.navigation.MotionParameters)
  ))
_sym_db.RegisterMessage(MotionParameters)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\024MotionParametersType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/math/Vec3DDouble.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/math/Vec3DDouble.proto',
  package='rst.math',
  syntax='proto2',
  serialized_pb=_b('\n\x1arst/math/Vec3DDouble.proto\x12\x08rst.math\"7\n\x0bVec3DDouble\x12\x0c\n\x01x\x18\x01 \x02(\x01:\x01\x30\x12\x0c\n\x01y\x18\x02 \x02(\x01:\x01\x30\x12\x0c\n\x01z\x18\x03 \x02(\x01:\x01\x30\x42\x11\x42\x0fVec3DDoubleType')
)




_VEC3DDOUBLE = _descriptor.Descriptor(
  name='Vec3DDouble',
  full_name='rst.math.Vec3DDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='rst.math.Vec3DDouble.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='rst.math.Vec3DDouble.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='rst.math.Vec3DDouble.z', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=95,
)

DESCRIPTOR.message_types_by_name['Vec3DDouble'] = _VEC3DDOUBLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Vec3DDouble = _reflection.GeneratedProtocolMessageType('Vec3DDouble', (_message.Message,), dict(
  DESCRIPTOR = _VEC3DDOUBLE,
  __module__ = 'rst.math.Vec3DDouble_pb2'
  # @@protoc_insertion_point(class_scope:rst.math.Vec3DDouble)
  ))
_sym_db.RegisterMessage(Vec3DDouble)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017Vec3DDoubleType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassificationResultMap.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.classification import ClassificationResult_pb2 as rst_dot_classification_dot_ClassificationResult__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassificationResultMap.proto',
  package='rst.classification',
  syntax='proto2',
  serialized_pb=_b('\n0rst/classification/ClassificationResultMap.proto\x12\x12rst.classification\x1a-rst/classification/ClassificationResult.proto\"\xae\x01\n\x17\x43lassificationResultMap\x12\x42\n\x07\x61spects\x18\x01 \x03(\x0b\x32\x31.rst.classification.ClassificationResultMap.Entry\x1aO\n\x05\x45ntry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x38\n\x06result\x18\x02 \x02(\x0b\x32(.rst.classification.ClassificationResultB\x1d\x42\x1b\x43lassificationResultMapType')
  ,
  dependencies=[rst_dot_classification_dot_ClassificationResult__pb2.DESCRIPTOR,])




_CLASSIFICATIONRESULTMAP_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='rst.classification.ClassificationResultMap.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.classification.ClassificationResultMap.Entry.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='rst.classification.ClassificationResultMap.Entry.result', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=294,
)

_CLASSIFICATIONRESULTMAP = _descriptor.Descriptor(
  name='ClassificationResultMap',
  full_name='rst.classification.ClassificationResultMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aspects', full_name='rst.classification.ClassificationResultMap.aspects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CLASSIFICATIONRESULTMAP_ENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=294,
)

_CLASSIFICATIONRESULTMAP_ENTRY.fields_by_name['result'].message_type = rst_dot_classification_dot_ClassificationResult__pb2._CLASSIFICATIONRESULT
_CLASSIFICATIONRESULTMAP_ENTRY.containing_type = _CLASSIFICATIONRESULTMAP
_CLASSIFICATIONRESULTMAP.fields_by_name['aspects'].message_type = _CLASSIFICATIONRESULTMAP_ENTRY
DESCRIPTOR.message_types_by_name['ClassificationResultMap'] = _CLASSIFICATIONRESULTMAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassificationResultMap = _reflection.GeneratedProtocolMessageType('ClassificationResultMap', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _CLASSIFICATIONRESULTMAP_ENTRY,
    __module__ = 'rst.classification.ClassificationResultMap_pb2'
    # @@protoc_insertion_point(class_scope:rst.classification.ClassificationResultMap.Entry)
    ))
  ,
  DESCRIPTOR = _CLASSIFICATIONRESULTMAP,
  __module__ = 'rst.classification.ClassificationResultMap_pb2'
  # @@protoc_insertion_point(class_scope:rst.classification.ClassificationResultMap)
  ))
_sym_db.RegisterMessage(ClassificationResultMap)
_sym_db.RegisterMessage(ClassificationResultMap.Entry)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\033ClassificationResultMapType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/PointPair.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.math import Vec2DFloat_pb2 as rst_dot_math_dot_Vec2DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/PointPair.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n\x1crst/geometry/PointPair.proto\x12\x0crst.geometry\x1a\x19rst/math/Vec2DFloat.proto\"V\n\tPointPair\x12#\n\x05\x66irst\x18\x01 \x02(\x0b\x32\x14.rst.math.Vec2DFloat\x12$\n\x06second\x18\x02 \x02(\x0b\x32\x14.rst.math.Vec2DFloatB\x0f\x42\rPointPairType')
  ,
  dependencies=[rst_dot_math_dot_Vec2DFloat__pb2.DESCRIPTOR,])




_POINTPAIR = _descriptor.Descriptor(
  name='PointPair',
  full_name='rst.geometry.PointPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='first', full_name='rst.geometry.PointPair.first', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='second', full_name='rst.geometry.PointPair.second', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=159,
)

_POINTPAIR.fields_by_name['first'].message_type = rst_dot_math_dot_Vec2DFloat__pb2._VEC2DFLOAT
_POINTPAIR.fields_by_name['second'].message_type = rst_dot_math_dot_Vec2DFloat__pb2._VEC2DFLOAT
DESCRIPTOR.message_types_by_name['PointPair'] = _POINTPAIR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PointPair = _reflection.GeneratedProtocolMessageType('PointPair', (_message.Message,), dict(
  DESCRIPTOR = _POINTPAIR,
  __module__ = 'rst.geometry.PointPair_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.PointPair)
  ))
_sym_db.RegisterMessage(PointPair)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rPointPairType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/RecurrenceRule.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.calendar import DateTime_pb2 as rst_dot_calendar_dot_DateTime__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/RecurrenceRule.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n!rst/calendar/RecurrenceRule.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\"\xa7\x05\n\x0eRecurrenceRule\x12.\n\x0euntil_date_utc\x18\x02 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x41\n\tfrequency\x18\x04 \x02(\x0e\x32&.rst.calendar.RecurrenceRule.Frequency:\x06YEARLY\x12\x13\n\x08interval\x18\x05 \x01(\r:\x01\x31\x12\x11\n\tby_second\x18\x06 \x03(\r\x12\x11\n\tby_minute\x18\x07 \x03(\r\x12\x0f\n\x07\x62y_hour\x18\x08 \x03(\r\x12\x39\n\x0b\x62y_week_day\x18\t \x03(\x0e\x32$.rst.calendar.RecurrenceRule.Weekday\x12\x15\n\rby_day_number\x18\n \x03(\x11\x12\x14\n\x0c\x62y_month_day\x18\x0b \x03(\x11\x12\x13\n\x0b\x62y_year_day\x18\x0c \x03(\x11\x12\x16\n\x0e\x62y_week_number\x18\r \x03(\x11\x12\x10\n\x08\x62y_month\x18\x0e \x03(\r\x12\x12\n\nby_set_pos\x18\x0f \x03(\x11\x12@\n\nweek_start\x18\x10 \x01(\x0e\x32$.rst.calendar.RecurrenceRule.Weekday:\x06MONDAY\"c\n\tFrequency\x12\x0c\n\x08SECONDLY\x10\x01\x12\x0c\n\x08MINUTELY\x10\x02\x12\n\n\x06HOURLY\x10\x03\x12\t\n\x05\x44\x41ILY\x10\x04\x12\n\n\x06WEEKLY\x10\x05\x12\x0b\n\x07MONTHLY\x10\x06\x12\n\n\x06YEARLY\x10\x07\"e\n\x07Weekday\x12\n\n\x06SUNDAY\x10\x01\x12\n\n\x06MONDAY\x10\x02\x12\x0b\n\x07TUESDAY\x10\x03\x12\r\n\tWEDNESDAY\x10\x04\x12\x0c\n\x08THURSDAY\x10\x05\x12\n\n\x06\x46RIDAY\x10\x06\x12\x0c\n\x08SATURDAY\x10\x07\x42\x14\x42\x12RecurrenceRuleType')
  ,
  dependencies=[rst_dot_calendar_dot_DateTime__pb2.DESCRIPTOR,])



_RECURRENCERULE_FREQUENCY = _descriptor.EnumDescriptor(
  name='Frequency',
  full_name='rst.calendar.RecurrenceRule.Frequency',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SECONDLY', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MINUTELY', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HOURLY', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DAILY', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKLY', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTHLY', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YEARLY', index=6, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=558,
  serialized_end=657,
)
_sym_db.RegisterEnumDescriptor(_RECURRENCERULE_FREQUENCY)

_RECURRENCERULE_WEEKDAY = _descriptor.EnumDescriptor(
  name='Weekday',
  full_name='rst.calendar.RecurrenceRule.Weekday',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUNDAY', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONDAY', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TUESDAY', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEDNESDAY', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THURSDAY', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FRIDAY', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SATURDAY', index=6, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=659,
  serialized_end=760,
)
_sym_db.RegisterEnumDescriptor(_RECURRENCERULE_WEEKDAY)


_RECURRENCERULE = _descriptor.Descriptor(
  name='RecurrenceRule',
  full_name='rst.calendar.RecurrenceRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='until_date_utc', full_name='rst.calendar.RecurrenceRule.until_date_utc', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count', full_name='rst.calendar.RecurrenceRule.count', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='rst.calendar.RecurrenceRule.frequency', index=2,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=True, default_value=7,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interval', full_name='rst.calendar.RecurrenceRule.interval', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_second', full_name='rst.calendar.RecurrenceRule.by_second', index=4,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_minute', full_name='rst.calendar.RecurrenceRule.by_minute', index=5,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_hour', full_name='rst.calendar.RecurrenceRule.by_hour', index=6,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_week_day', full_name='rst.calendar.RecurrenceRule.by_week_day', index=7,
      number=9, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_day_number', full_name='rst.calendar.RecurrenceRule.by_day_number', index=8,
      number=10, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_month_day', full_name='rst.calendar.RecurrenceRule.by_month_day', index=9,
      number=11, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_year_day', full_name='rst.calendar.RecurrenceRule.by_year_day', index=10,
      number=12, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_week_number', full_name='rst.calendar.RecurrenceRule.by_week_number', index=11,
      number=13, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_month', full_name='rst.calendar.RecurrenceRule.by_month', index=12,
      number=14, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='by_set_pos', full_name='rst.calendar.RecurrenceRule.by_set_pos', index=13,
      number=15, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='week_start', full_name='rst.calendar.RecurrenceRule.week_start', index=14,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RECURRENCERULE_FREQUENCY,
    _RECURRENCERULE_WEEKDAY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=760,
)

_RECURRENCERULE.fields_by_name['until_date_utc'].message_type = rst_dot_calendar_dot_DateTime__pb2._DATETIME
_RECURRENCERULE.fields_by_name['frequency'].enum_type = _RECURRENCERULE_FREQUENCY
_RECURRENCERULE.fields_by_name['by_week_day'].enum_type = _RECURRENCERULE_WEEKDAY
_RECURRENCERULE.fields_by_name['week_start'].enum_type = _RECURRENCERULE_WEEKDAY
_RECURRENCERULE_FREQUENCY.containing_type = _RECURRENCERULE
_RECURRENCERULE_WEEKDAY.containing_type = _RECURRENCERULE
DESCRIPTOR.message_types_by_name['RecurrenceRule'] = _RECURRENCERULE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecurrenceRule = _reflection.GeneratedProtocolMessageType('RecurrenceRule', (_message.Message,), dict(
  DESCRIPTOR = _RECURRENCERULE,
  __module__ = 'rst.calendar.RecurrenceRule_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.RecurrenceRule)
  ))
_sym_db.RegisterMessage(RecurrenceRule)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\022RecurrenceRuleType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/timing/Frequency.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/timing/Frequency.proto',
  package='rst.timing',
  syntax='proto2',
  serialized_pb=_b('\n\x1arst/timing/Frequency.proto\x12\nrst.timing\"\x17\n\tFrequency\x12\n\n\x02hz\x18\x01 \x02(\x01\x42\x0f\x42\rFrequencyType')
)




_FREQUENCY = _descriptor.Descriptor(
  name='Frequency',
  full_name='rst.timing.Frequency',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hz', full_name='rst.timing.Frequency.hz', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=65,
)

DESCRIPTOR.message_types_by_name['Frequency'] = _FREQUENCY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Frequency = _reflection.GeneratedProtocolMessageType('Frequency', (_message.Message,), dict(
  DESCRIPTOR = _FREQUENCY,
  __module__ = 'rst.timing.Frequency_pb2'
  # @@protoc_insertion_point(class_scope:rst.timing.Frequency)
  ))
_sym_db.RegisterMessage(Frequency)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rFrequencyType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/ViewFrustum.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import FieldOfView_pb2 as rst_dot_geometry_dot_FieldOfView__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/ViewFrustum.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n\x1erst/geometry/ViewFrustum.proto\x12\x0crst.geometry\x1a\x1erst/geometry/FieldOfView.proto\"s\n\x0bViewFrustum\x12&\n\x03\x66ov\x18\x01 \x02(\x0b\x32\x19.rst.geometry.FieldOfView\x12\x1b\n\x10minimal_distance\x18\x02 \x01(\x02:\x01\x30\x12\x1f\n\x10maximal_distance\x18\x03 \x01(\x02:\x05\x39\x39\x39\x39\x39\x42\x11\x42\x0fViewFrustumType')
  ,
  dependencies=[rst_dot_geometry_dot_FieldOfView__pb2.DESCRIPTOR,])




_VIEWFRUSTUM = _descriptor.Descriptor(
  name='ViewFrustum',
  full_name='rst.geometry.ViewFrustum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fov', full_name='rst.geometry.ViewFrustum.fov', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='minimal_distance', full_name='rst.geometry.ViewFrustum.minimal_distance', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maximal_distance', full_name='rst.geometry.ViewFrustum.maximal_distance', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(99999),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=195,
)

_VIEWFRUSTUM.fields_by_name['fov'].message_type = rst_dot_geometry_dot_FieldOfView__pb2._FIELDOFVIEW
DESCRIPTOR.message_types_by_name['ViewFrustum'] = _VIEWFRUSTUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ViewFrustum = _reflection.GeneratedProtocolMessageType('ViewFrustum', (_message.Message,), dict(
  DESCRIPTOR = _VIEWFRUSTUM,
  __module__ = 'rst.geometry.ViewFrustum_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.ViewFrustum)
  ))
_sym_db.RegisterMessage(ViewFrustum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\017ViewFrustumType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/stochastics/Gaussian1D.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/stochastics/Gaussian1D.proto',
  package='rst.stochastics',
  syntax='proto2',
  serialized_pb=_b('\n rst/stochastics/Gaussian1D.proto\x12\x0frst.stochastics\",\n\nGaussian1D\x12\x0c\n\x04mean\x18\x01 \x02(\x02\x12\x10\n\x08variance\x18\x02 \x02(\x02\x42\x10\x42\x0eGaussian1DType')
)




_GAUSSIAN1D = _descriptor.Descriptor(
  name='Gaussian1D',
  full_name='rst.stochastics.Gaussian1D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mean', full_name='rst.stochastics.Gaussian1D.mean', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='variance', full_name='rst.stochastics.Gaussian1D.variance', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=97,
)

DESCRIPTOR.message_types_by_name['Gaussian1D'] = _GAUSSIAN1D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Gaussian1D = _reflection.GeneratedProtocolMessageType('Gaussian1D', (_message.Message,), dict(
  DESCRIPTOR = _GAUSSIAN1D,
  __module__ = 'rst.stochastics.Gaussian1D_pb2'
  # @@protoc_insertion_point(class_scope:rst.stochastics.Gaussian1D)
  ))
_sym_db.RegisterMessage(Gaussian1D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\016Gaussian1DType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dynamics/MotorCurrents.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dynamics/MotorCurrents.proto',
  package='rst.dynamics',
  syntax='proto2',
  serialized_pb=_b('\n rst/dynamics/MotorCurrents.proto\x12\x0crst.dynamics\"%\n\rMotorCurrents\x12\x14\n\x08\x63urrents\x18\x01 \x03(\x02\x42\x02\x10\x01\x42\x13\x42\x11MotorCurrentsType')
)




_MOTORCURRENTS = _descriptor.Descriptor(
  name='MotorCurrents',
  full_name='rst.dynamics.MotorCurrents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currents', full_name='rst.dynamics.MotorCurrents.currents', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=87,
)

DESCRIPTOR.message_types_by_name['MotorCurrents'] = _MOTORCURRENTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MotorCurrents = _reflection.GeneratedProtocolMessageType('MotorCurrents', (_message.Message,), dict(
  DESCRIPTOR = _MOTORCURRENTS,
  __module__ = 'rst.dynamics.MotorCurrents_pb2'
  # @@protoc_insertion_point(class_scope:rst.dynamics.MotorCurrents)
  ))
_sym_db.RegisterMessage(MotorCurrents)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\021MotorCurrentsType'))
_MOTORCURRENTS.fields_by_name['currents'].has_options = True
_MOTORCURRENTS.fields_by_name['currents']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/Rotation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/Rotation.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n\x1brst/geometry/Rotation.proto\x12\x0crst.geometry\"L\n\x08Rotation\x12\n\n\x02qw\x18\x04 \x02(\x01\x12\n\n\x02qx\x18\x05 \x02(\x01\x12\n\n\x02qy\x18\x06 \x02(\x01\x12\n\n\x02qz\x18\x07 \x02(\x01\x12\x10\n\x08\x66rame_id\x18\x08 \x01(\tB\x0e\x42\x0cRotationType')
)




_ROTATION = _descriptor.Descriptor(
  name='Rotation',
  full_name='rst.geometry.Rotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='qw', full_name='rst.geometry.Rotation.qw', index=0,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='qx', full_name='rst.geometry.Rotation.qx', index=1,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='qy', full_name='rst.geometry.Rotation.qy', index=2,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='qz', full_name='rst.geometry.Rotation.qz', index=3,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='rst.geometry.Rotation.frame_id', index=4,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=121,
)

DESCRIPTOR.message_types_by_name['Rotation'] = _ROTATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Rotation = _reflection.GeneratedProtocolMessageType('Rotation', (_message.Message,), dict(
  DESCRIPTOR = _ROTATION,
  __module__ = 'rst.geometry.Rotation_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.Rotation)
  ))
_sym_db.RegisterMessage(Rotation)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\014RotationType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/PolygonalPatch3D.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Pose_pb2 as rst_dot_geometry_dot_Pose__pb2
from rst.math import Vec2DFloat_pb2 as rst_dot_math_dot_Vec2DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/PolygonalPatch3D.proto',
  package='rst.geometry',
  syntax='proto2',
  serialized_pb=_b('\n#rst/geometry/PolygonalPatch3D.proto\x12\x0crst.geometry\x1a\x17rst/geometry/Pose.proto\x1a\x19rst/math/Vec2DFloat.proto\"Z\n\x10PolygonalPatch3D\x12 \n\x04\x62\x61se\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12$\n\x06\x62order\x18\x02 \x03(\x0b\x32\x14.rst.math.Vec2DFloatB\x16\x42\x14PolygonalPatch3DType')
  ,
  dependencies=[rst_dot_geometry_dot_Pose__pb2.DESCRIPTOR,rst_dot_math_dot_Vec2DFloat__pb2.DESCRIPTOR,])




_POLYGONALPATCH3D = _descriptor.Descriptor(
  name='PolygonalPatch3D',
  full_name='rst.geometry.PolygonalPatch3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='rst.geometry.PolygonalPatch3D.base', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='border', full_name='rst.geometry.PolygonalPatch3D.border', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=195,
)

_POLYGONALPATCH3D.fields_by_name['base'].message_type = rst_dot_geometry_dot_Pose__pb2._POSE
_POLYGONALPATCH3D.fields_by_name['border'].message_type = rst_dot_math_dot_Vec2DFloat__pb2._VEC2DFLOAT
DESCRIPTOR.message_types_by_name['PolygonalPatch3D'] = _POLYGONALPATCH3D
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PolygonalPatch3D = _reflection.GeneratedProtocolMessageType('PolygonalPatch3D', (_message.Message,), dict(
  DESCRIPTOR = _POLYGONALPATCH3D,
  __module__ = 'rst.geometry.PolygonalPatch3D_pb2'
  # @@protoc_insertion_point(class_scope:rst.geometry.PolygonalPatch3D)
  ))
_sym_db.RegisterMessage(PolygonalPatch3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\024PolygonalPatch3DType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/Body.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.geometry import Translation_pb2 as rst_dot_geometry_dot_Translation__pb2
from rst.geometry import Rotation_pb2 as rst_dot_geometry_dot_Rotation__pb2
from rst.geometry import BoundingBox3DFloat_pb2 as rst_dot_geometry_dot_BoundingBox3DFloat__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/Body.proto',
  package='rst.hri',
  syntax='proto2',
  serialized_pb=_b('\n\x12rst/hri/Body.proto\x12\x07rst.hri\x1a\x1erst/geometry/Translation.proto\x1a\x1brst/geometry/Rotation.proto\x1a%rst/geometry/BoundingBox3DFloat.proto\"\x91\x01\n\x04\x42ody\x12+\n\x08location\x18\n \x01(\x0b\x32\x19.rst.geometry.Translation\x12+\n\x0borientation\x18\x14 \x01(\x0b\x32\x16.rst.geometry.Rotation\x12/\n\x05shape\x18\x1e \x01(\x0b\x32 .rst.geometry.BoundingBox3DFloatB\nB\x08\x42odyType')
  ,
  dependencies=[rst_dot_geometry_dot_Translation__pb2.DESCRIPTOR,rst_dot_geometry_dot_Rotation__pb2.DESCRIPTOR,rst_dot_geometry_dot_BoundingBox3DFloat__pb2.DESCRIPTOR,])




_BODY = _descriptor.Descriptor(
  name='Body',
  full_name='rst.hri.Body',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='rst.hri.Body.location', index=0,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='rst.hri.Body.orientation', index=1,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shape', full_name='rst.hri.Body.shape', index=2,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=277,
)

_BODY.fields_by_name['location'].message_type = rst_dot_geometry_dot_Translation__pb2._TRANSLATION
_BODY.fields_by_name['orientation'].message_type = rst_dot_geometry_dot_Rotation__pb2._ROTATION
_BODY.fields_by_name['shape'].message_type = rst_dot_geometry_dot_BoundingBox3DFloat__pb2._BOUNDINGBOX3DFLOAT
DESCRIPTOR.message_types_by_name['Body'] = _BODY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Body = _reflection.GeneratedProtocolMessageType('Body', (_message.Message,), dict(
  DESCRIPTOR = _BODY,
  __module__ = 'rst.hri.Body_pb2'
  # @@protoc_insertion_point(class_scope:rst.hri.Body)
  ))
_sym_db.RegisterMessage(Body)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\010BodyType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Relationship.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Relationship.proto',
  package='rst.calendar',
  syntax='proto2',
  serialized_pb=_b('\n\x1frst/calendar/Relationship.proto\x12\x0crst.calendar\"\x8b\x01\n\x0cRelationship\x12\x42\n\x11relationship_type\x18\x01 \x01(\x0e\x32\x1f.rst.calendar.Relationship.Type:\x06PARENT\x12\x0b\n\x03uid\x18\x02 \x02(\t\"*\n\x04Type\x12\n\n\x06PARENT\x10\x01\x12\t\n\x05\x43HILD\x10\x02\x12\x0b\n\x07SIBLING\x10\x03\x42\x12\x42\x10RelationshipType')
)



_RELATIONSHIP_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='rst.calendar.Relationship.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARENT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHILD', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIBLING', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=147,
  serialized_end=189,
)
_sym_db.RegisterEnumDescriptor(_RELATIONSHIP_TYPE)


_RELATIONSHIP = _descriptor.Descriptor(
  name='Relationship',
  full_name='rst.calendar.Relationship',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relationship_type', full_name='rst.calendar.Relationship.relationship_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uid', full_name='rst.calendar.Relationship.uid', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RELATIONSHIP_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=189,
)

_RELATIONSHIP.fields_by_name['relationship_type'].enum_type = _RELATIONSHIP_TYPE
_RELATIONSHIP_TYPE.containing_type = _RELATIONSHIP
DESCRIPTOR.message_types_by_name['Relationship'] = _RELATIONSHIP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Relationship = _reflection.GeneratedProtocolMessageType('Relationship', (_message.Message,), dict(
  DESCRIPTOR = _RELATIONSHIP,
  __module__ = 'rst.calendar.Relationship_pb2'
  # @@protoc_insertion_point(class_scope:rst.calendar.Relationship)
  ))
_sym_db.RegisterMessage(Relationship)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\020RelationshipType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/HighlightTarget.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Duration_pb2 as rst_dot_timing_dot_Duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/HighlightTarget.proto',
  package='rst.hri',
  syntax='proto2',
  serialized_pb=_b('\n\x1drst/hri/HighlightTarget.proto\x12\x07rst.hri\x1a\x19rst/timing/Duration.proto\"\xd2\x01\n\x0fHighlightTarget\x12\x11\n\ttarget_id\x18\x01 \x02(\t\x12&\n\x08\x64uration\x18\x02 \x02(\x0b\x32\x14.rst.timing.Duration\x12\x33\n\x08modality\x18\x03 \x03(\x0e\x32!.rst.hri.HighlightTarget.Modality\"O\n\x08Modality\x12\x08\n\x04GAZE\x10\x01\x12\x0b\n\x07GESTURE\x10\x02\x12\x11\n\rAMBIENT_LIGHT\x10\x03\x12\t\n\x05SOUND\x10\x04\x12\x0e\n\nSPOT_LIGHT\x10\x05\x42\x15\x42\x13HighlightTargetType')
  ,
  dependencies=[rst_dot_timing_dot_Duration__pb2.DESCRIPTOR,])



_HIGHLIGHTTARGET_MODALITY = _descriptor.EnumDescriptor(
  name='Modality',
  full_name='rst.hri.HighlightTarget.Modality',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GAZE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GESTURE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AMBIENT_LIGHT', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOUND', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPOT_LIGHT', index=4, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=201,
  serialized_end=280,
)
_sym_db.RegisterEnumDescriptor(_HIGHLIGHTTARGET_MODALITY)


_HIGHLIGHTTARGET = _descriptor.Descriptor(
  name='HighlightTarget',
  full_name='rst.hri.HighlightTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_id', full_name='rst.hri.HighlightTarget.target_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='rst.hri.HighlightTarget.duration', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modality', full_name='rst.hri.HighlightTarget.modality', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HIGHLIGHTTARGET_MODALITY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=280,
)

_HIGHLIGHTTARGET.fields_by_name['duration'].message_type = rst_dot_timing_dot_Duration__pb2._DURATION
_HIGHLIGHTTARGET.fields_by_name['modality'].enum_type = _HIGHLIGHTTARGET_MODALITY
_HIGHLIGHTTARGET_MODALITY.containing_type = _HIGHLIGHTTARGET
DESCRIPTOR.message_types_by_name['HighlightTarget'] = _HIGHLIGHTTARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HighlightTarget = _reflection.GeneratedProtocolMessageType('HighlightTarget', (_message.Message,), dict(
  DESCRIPTOR = _HIGHLIGHTTARGET,
  __module__ = 'rst.hri.HighlightTarget_pb2'
  # @@protoc_insertion_point(class_scope:rst.hri.HighlightTarget)
  ))
_sym_db.RegisterMessage(HighlightTarget)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\023HighlightTargetType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/AngularAccelerations.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/AngularAccelerations.proto',
  package='rst.kinematics',
  syntax='proto2',
  serialized_pb=_b('\n)rst/kinematics/AngularAccelerations.proto\x12\x0erst.kinematics\"7\n\x14\x41ngularAccelerations\x12\t\n\x01\x61\x18\x01 \x02(\x02\x12\t\n\x01\x62\x18\x02 \x02(\x02\x12\t\n\x01\x63\x18\x03 \x02(\x02\x42\x1a\x42\x18\x41ngularAccelerationsType')
)




_ANGULARACCELERATIONS = _descriptor.Descriptor(
  name='AngularAccelerations',
  full_name='rst.kinematics.AngularAccelerations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='rst.kinematics.AngularAccelerations.a', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='b', full_name='rst.kinematics.AngularAccelerations.b', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c', full_name='rst.kinematics.AngularAccelerations.c', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=116,
)

DESCRIPTOR.message_types_by_name['AngularAccelerations'] = _ANGULARACCELERATIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AngularAccelerations = _reflection.GeneratedProtocolMessageType('AngularAccelerations', (_message.Message,), dict(
  DESCRIPTOR = _ANGULARACCELERATIONS,
  __module__ = 'rst.kinematics.AngularAccelerations_pb2'
  # @@protoc_insertion_point(class_scope:rst.kinematics.AngularAccelerations)
  ))
_sym_db.RegisterMessage(AngularAccelerations)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\030AngularAccelerationsType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/DiskState.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/DiskState.proto',
  package='rst.devices.generic',
  syntax='proto2',
  serialized_pb=_b('\n#rst/devices/generic/DiskState.proto\x12\x13rst.devices.generic\"\xee\x02\n\tDiskState\x12<\n\npartitions\x18\x01 \x03(\x0b\x32(.rst.devices.generic.DiskState.Partition\x12\x36\n\x07\x64\x65vices\x18\x02 \x03(\x0b\x32%.rst.devices.generic.DiskState.Device\x1aY\n\tPartition\x12\x13\n\x0bmount_point\x18\x01 \x02(\x0c\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x0c\x12\x13\n\x0bspace_total\x18\n \x01(\x04\x12\x12\n\nspace_used\x18\x0b \x01(\x04\x1a\x8f\x01\n\x06\x44\x65vice\x12\x0c\n\x04name\x18\x01 \x02(\x0c\x12\x12\n\nread_count\x18\n \x01(\x04\x12\x13\n\x0bwrite_count\x18\x0b \x01(\x04\x12\x12\n\nread_bytes\x18\x0c \x01(\x04\x12\x13\n\x0bwrite_bytes\x18\r \x01(\x04\x12\x11\n\tread_time\x18\x0e \x01(\x04\x12\x12\n\nwrite_time\x18\x0f \x01(\x04\x42\x0f\x42\rDiskStateType')
)




_DISKSTATE_PARTITION = _descriptor.Descriptor(
  name='Partition',
  full_name='rst.devices.generic.DiskState.Partition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mount_point', full_name='rst.devices.generic.DiskState.Partition.mount_point', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device', full_name='rst.devices.generic.DiskState.Partition.device', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='space_total', full_name='rst.devices.generic.DiskState.Partition.space_total', index=2,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='space_used', full_name='rst.devices.generic.DiskState.Partition.space_used', index=3,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=281,
)

_DISKSTATE_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='rst.devices.generic.DiskState.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.generic.DiskState.Device.name', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='read_count', full_name='rst.devices.generic.DiskState.Device.read_count', index=1,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='write_count', full_name='rst.devices.generic.DiskState.Device.write_count', index=2,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='read_bytes', full_name='rst.devices.generic.DiskState.Device.read_bytes', index=3,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='write_bytes', full_name='rst.devices.generic.DiskState.Device.write_bytes', index=4,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='read_time', full_name='rst.devices.generic.DiskState.Device.read_time', index=5,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='write_time', full_name='rst.devices.generic.DiskState.Device.write_time', index=6,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=427,
)

_DISKSTATE = _descriptor.Descriptor(
  name='DiskState',
  full_name='rst.devices.generic.DiskState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partitions', full_name='rst.devices.generic.DiskState.partitions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='devices', full_name='rst.devices.generic.DiskState.devices', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_DISKSTATE_PARTITION, _DISKSTATE_DEVICE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=427,
)

_DISKSTATE_PARTITION.containing_type = _DISKSTATE
_DISKSTATE_DEVICE.containing_type = _DISKSTATE
_DISKSTATE.fields_by_name['partitions'].message_type = _DISKSTATE_PARTITION
_DISKSTATE.fields_by_name['devices'].message_type = _DISKSTATE_DEVICE
DESCRIPTOR.message_types_by_name['DiskState'] = _DISKSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DiskState = _reflection.GeneratedProtocolMessageType('DiskState', (_message.Message,), dict(

  Partition = _reflection.GeneratedProtocolMessageType('Partition', (_message.Message,), dict(
    DESCRIPTOR = _DISKSTATE_PARTITION,
    __module__ = 'rst.devices.generic.DiskState_pb2'
    # @@protoc_insertion_point(class_scope:rst.devices.generic.DiskState.Partition)
    ))
  ,

  Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), dict(
    DESCRIPTOR = _DISKSTATE_DEVICE,
    __module__ = 'rst.devices.generic.DiskState_pb2'
    # @@protoc_insertion_point(class_scope:rst.devices.generic.DiskState.Device)
    ))
  ,
  DESCRIPTOR = _DISKSTATE,
  __module__ = 'rst.devices.generic.DiskState_pb2'
  # @@protoc_insertion_point(class_scope:rst.devices.generic.DiskState)
  ))
_sym_db.RegisterMessage(DiskState)
_sym_db.RegisterMessage(DiskState.Partition)
_sym_db.RegisterMessage(DiskState.Device)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\rDiskStateType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/bayesnetwork/BayesNetworkEvidence.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.timing import Timestamp_pb2 as rst_dot_timing_dot_Timestamp__pb2
from rst.bayesnetwork import BayesNetwork_pb2 as rst_dot_bayesnetwork_dot_BayesNetwork__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/bayesnetwork/BayesNetworkEvidence.proto',
  package='rst.bayesnetwork',
  syntax='proto2',
  serialized_pb=_b('\n+rst/bayesnetwork/BayesNetworkEvidence.proto\x12\x10rst.bayesnetwork\x1a\x1arst/timing/Timestamp.proto\x1a#rst/bayesnetwork/BayesNetwork.proto\"\x89\x02\n\x14\x42\x61yesNetworkEvidence\x12/\n\x07network\x18\x01 \x01(\x0b\x32\x1e.rst.bayesnetwork.BayesNetwork\x12#\n\x04time\x18\x02 \x01(\x0b\x32\x15.rst.timing.Timestamp\x12\x1d\n\x15\x64uration_microseconds\x18\x04 \x01(\x04\x12J\n\x0cobservations\x18\x03 \x03(\x0b\x32\x34.rst.bayesnetwork.BayesNetworkEvidence.VariableState\x1a\x30\n\rVariableState\x12\x10\n\x08variable\x18\x01 \x02(\t\x12\r\n\x05state\x18\x02 \x02(\tB\x1a\x42\x18\x42\x61yesNetworkEvidenceType')
  ,
  dependencies=[rst_dot_timing_dot_Timestamp__pb2.DESCRIPTOR,rst_dot_bayesnetwork_dot_BayesNetwork__pb2.DESCRIPTOR,])




_BAYESNETWORKEVIDENCE_VARIABLESTATE = _descriptor.Descriptor(
  name='VariableState',
  full_name='rst.bayesnetwork.BayesNetworkEvidence.VariableState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable', full_name='rst.bayesnetwork.BayesNetworkEvidence.VariableState.variable', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='rst.bayesnetwork.BayesNetworkEvidence.VariableState.state', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=396,
)

_BAYESNETWORKEVIDENCE = _descriptor.Descriptor(
  name='BayesNetworkEvidence',
  full_name='rst.bayesnetwork.BayesNetworkEvidence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='network', full_name='rst.bayesnetwork.BayesNetworkEvidence.network', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='rst.bayesnetwork.BayesNetworkEvidence.time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration_microseconds', full_name='rst.bayesnetwork.BayesNetworkEvidence.duration_microseconds', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='observations', full_name='rst.bayesnetwork.BayesNetworkEvidence.observations', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_BAYESNETWORKEVIDENCE_VARIABLESTATE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=396,
)

_BAYESNETWORKEVIDENCE_VARIABLESTATE.containing_type = _BAYESNETWORKEVIDENCE
_BAYESNETWORKEVIDENCE.fields_by_name['network'].message_type = rst_dot_bayesnetwork_dot_BayesNetwork__pb2._BAYESNETWORK
_BAYESNETWORKEVIDENCE.fields_by_name['time'].message_type = rst_dot_timing_dot_Timestamp__pb2._TIMESTAMP
_BAYESNETWORKEVIDENCE.fields_by_name['observations'].message_type = _BAYESNETWORKEVIDENCE_VARIABLESTATE
DESCRIPTOR.message_types_by_name['BayesNetworkEvidence'] = _BAYESNETWORKEVIDENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BayesNetworkEvidence = _reflection.GeneratedProtocolMessageType('BayesNetworkEvidence', (_message.Message,), dict(

  VariableState = _reflection.GeneratedProtocolMessageType('VariableState', (_message.Message,), dict(
    DESCRIPTOR = _BAYESNETWORKEVIDENCE_VARIABLESTATE,
    __module__ = 'rst.bayesnetwork.BayesNetworkEvidence_pb2'
    # @@protoc_insertion_point(class_scope:rst.bayesnetwork.BayesNetworkEvidence.VariableState)
    ))
  ,
  DESCRIPTOR = _BAYESNETWORKEVIDENCE,
  __module__ = 'rst.bayesnetwork.BayesNetworkEvidence_pb2'
  # @@protoc_insertion_point(class_scope:rst.bayesnetwork.BayesNetworkEvidence)
  ))
_sym_db.RegisterMessage(BayesNetworkEvidence)
_sym_db.RegisterMessage(BayesNetworkEvidence.VariableState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\030BayesNetworkEvidenceType'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/FaceLandmarks.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rst.math import Vec2DInt_pb2 as rst_dot_math_dot_Vec2DInt__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/FaceLandmarks.proto',
  package='rst.vision',
  syntax='proto2',
  serialized_pb=_b('\n\x1erst/vision/FaceLandmarks.proto\x12\nrst.vision\x1a\x17rst/math/Vec2DInt.proto\"\xe6\x02\n\rFaceLandmarks\x12\x1f\n\x03jaw\x18\x01 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12 \n\x04nose\x18\x02 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12&\n\nnose_wings\x18\x03 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12&\n\nright_brow\x18\x04 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12%\n\tleft_brow\x18\x05 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12%\n\tright_eye\x18\x06 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12$\n\x08left_eye\x18\x07 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12&\n\nouter_lips\x18\x08 \x03(\x0b\x32\x12.rst.math.Vec2DInt\x12&\n\ninner_lips\x18\t \x03(\x0b\x32\x12.rst.math.Vec2DIntB\x13\x42\x11\x46\x61\x63\x65LandmarksType')
  ,
  dependencies=[rst_dot_math_dot_Vec2DInt__pb2.DESCRIPTOR,])




_FACELANDMARKS = _descriptor.Descriptor(
  name='FaceLandmarks',
  full_name='rst.vision.FaceLandmarks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jaw', full_name='rst.vision.FaceLandmarks.jaw', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nose', full_name='rst.vision.FaceLandmarks.nose', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nose_wings', full_name='rst.vision.FaceLandmarks.nose_wings', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='right_brow', full_name='rst.vision.FaceLandmarks.right_brow', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='left_brow', full_name='rst.vision.FaceLandmarks.left_brow', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='right_eye', full_name='rst.vision.FaceLandmarks.right_eye', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='left_eye', full_name='rst.vision.FaceLandmarks.left_eye', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='outer_lips', full_name='rst.vision.FaceLandmarks.outer_lips', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inner_lips', full_name='rst.vision.FaceLandmarks.inner_lips', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=430,
)

_FACELANDMARKS.fields_by_name['jaw'].message_type = rst_dot_math_dot_Vec2DInt__pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['nose'].message_type = rst_dot_math_dot_Vec2DInt__pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['nose_wings'].message_type = rst_dot_math_dot_Vec2DInt__pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['right_brow'].message_type = rst_dot_math_dot_Vec2DInt__pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['left_brow'].message_type = rst_dot_math_dot_Vec2DInt__pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['right_eye'].message_type = rst_dot_math_dot_Vec2DInt__pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['left_eye'].message_type = rst_dot_math_dot_Vec2DInt__pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['outer_lips'].message_type = rst_dot_math_dot_Vec2DInt__pb2._VEC2DINT
_FACELANDMARKS.fields_by_name['inner_lips'].message_type = rst_dot_math_dot_Vec2DInt__pb2._VEC2DINT
DESCRIPTOR.message_types_by_name['FaceLandmarks'] = _FACELANDMARKS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceLandmarks = _reflection.GeneratedProtocolMessageType('FaceLandmarks', (_message.Message,), dict(
  DESCRIPTOR = _FACELANDMARKS,
  __module__ = 'rst.vision.FaceLandmarks_pb2'
  # @@protoc_insertion_point(class_scope:rst.vision.FaceLandmarks)
  ))
_sym_db.RegisterMessage(FaceLandmarks)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('B\021FaceLandmarksType'))
# @@protoc_insertion_point(module_scope)
